import { API_URL } from '$env/static/private';

import { redirect } from '@sveltejs/kit';

import type { LeaderboardEvent } from '$lib/types';

import type { PageServerLoad } from './$types';

export const load = (async ({ parent, fetch, cookies, params: { chapterId } }) => {
	await parent();

	if (!chapterId) {
		throw redirect(303, '/dashboard');
	}

	const session = cookies.get('session');

	const res = await fetch(`${API_URL}/leaderboard/${chapterId}`, {
		headers: {
			Authorization: `Bearer ${session}`
		}
	});

	if (!res.ok) {
		throw redirect(303, '/dashboard');
	}

	const leaderboard = (await res.json()) as LeaderboardEvent;

	if (!leaderboard || !leaderboard.groups.length) {
		throw redirect(303, '/dashboard');
	}

	return {
		leaderboard
	};
}) satisfies PageServerLoad;
